@@ -370,6 +370,96 @@ class ConfidantClient(object):
         ret['result'] = True
         return ret
 
+    def get_credential(self, id):
+        """Get a credential from ID."""
+        # Return a dict, always with an attribute that specifies whether or not
+        # the function was able to successfully get a result.
+        ret = {'result': False}
+
+        # Make a request to confidant with the provided url, to fetch the
+        # service providing the service name and base64 encoded
+        # token for authentication.
+        try:
+            response = self._execute_request(
+                'get',
+                '{0}/v1/credentials/{1}'.format(self.config['url'], id),
+                expected_return_codes=[200, 404]
+            )
+        except RequestExecutionError:
+            logging.exception('Error with executing request')
+            return ret
+
+        if response.status_code == 404:
+            logging.debug('Credential not found in confidant.')
+            ret['result'] = False
+            return ret
+
+        try:
+            data = response.json()
+        except ValueError:
+            logging.error('Received badly formatted json data from confidant.')
+            return ret
+
+        ret['credential'] = data
+        ret['result'] = True
+        return ret
+
+    def update_credential(
+            self,
+            id,
+            name=None,
+            credential_pairs=None,
+            metadata=None,
+            enabled=None,
+            documentation=None
+    ):
+        """Update a credential in Confidant."""
+        # Return a dict, always with an attribute that specifies whether or not
+        # the function was able to successfully get a result.
+        ret = {'result': False}
+        cred = self.get_credential(id)
+        if not cred['result']:
+            return ret
+
+        data_to_update = {}
+
+        if credential_pairs:
+            data_to_update['credential_pairs'] = credential_pairs
+        else:
+            # required for updating other fields
+            data_to_update['credential_pairs'] = \
+                cred['credential']['credential_pairs']
+
+        if name:
+            data_to_update['name'] = name
+        if metadata:
+            data_to_update['metadata'] = metadata
+        if documentation:
+            data_to_update['documentation'] = documentation
+        if enabled:
+            data_to_update['enabled'] = enabled
+
+        try:
+            response = self._execute_request(
+                'put',
+                '{0}/v1/credentials/{1}'.format(self.config['url'], id),
+                headers=JSON_HEADERS,
+                data=json.dumps(data_to_update)
+            )
+        except RequestExecutionError:
+            logging.exception('Error with executing request')
+            return ret
+
+        try:
+            data = response.json()
+        except ValueError:
+            logging.error('Received badly formatted json data from confidant.')
+            return ret
+
+        ret['credential'] = data
+        ret['result'] = True
+        return ret
+
     def _decrypt_blind_credentials(self, blind_credentials):
         _blind_credentials = []
         for blind_credential in blind_credentials:
